@@ -39,4 +39,8 @@ def Rhombus(height,width):
 def Polygon(sides,sidelength,apothem):
     perimeter=sidelength*sides
     area=(perimeter*apothem)/2
-    return areas
\ No newline at end of file
+    return areas
+
+def Kite(height,width):
+    area=(height*width)/2
+    return area
\ No newline at end of file
